@@ -2,5 +2,5 @@ from pathlib import Path
 
 base_directory = Path(__file__).resolve().parent
 CORTEX_ROOT = base_directory / "ext/cortex"
-STAMPY_SCRIPT = base_directory / "ext/stampy-1.0.32/stampy.py"
+MINIMAP2 = base_directory / "ext/minimap2"
 VCFTOOLS_DIRECTORY = base_directory / "ext/vcftools"
